@@ -4,8 +4,9 @@
 from __future__ import annotations
 
 import heapq
+from contextlib import suppress
+from math import isnan
 from typing import (
-    TYPE_CHECKING,
     Any,
     Callable,
     Collection,
@@ -18,16 +19,14 @@ from typing import (
 
 from rapidfuzz._utils import ScorerFlag
 from rapidfuzz.fuzz import WRatio, ratio
-from rapidfuzz.utils import default_process
-from math import isnan
 
 __all__ = ["extract", "extract_iter", "extractOne", "cdist"]
 
 
-def _get_scorer_flags_py(scorer: Any, kwargs: dict[str, Any]) -> tuple[int, int]:
+def _get_scorer_flags_py(scorer: Any, scorer_kwargs: dict[str, Any]) -> tuple[int, int]:
     params = getattr(scorer, "_RF_ScorerPy", None)
     if params is not None:
-        flags = params["get_scorer_flags"](**kwargs)
+        flags = params["get_scorer_flags"](**scorer_kwargs)
         return (flags["worst_score"], flags["optimal_score"])
     return (0, 100)
 
@@ -48,10 +47,10 @@ def extract_iter(
     choices: Iterable[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, int]]:
     ...
 
@@ -62,24 +61,23 @@ def extract_iter(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]:
     ...
 
 
 def extract_iter(
     query: Sequence[Hashable] | None,
-    choices: Iterable[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Iterable[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]:
     """
     Find the best match in a list of choices
@@ -98,20 +96,20 @@ def extract_iter(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Yields
     -------
@@ -124,11 +122,11 @@ def extract_iter(
         * The second value represents the similarity calculated by the scorer. This can be:
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
-            In this case only choices which have a `distance <= max` are yielded.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            In this case only choices which have a `distance <= score_cutoff` are yielded.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are yielded.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -138,17 +136,14 @@ def extract_iter(
           * The `key of choice` when choices is a mapping like a dict, or a pandas Series
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    _ = score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
     if _is_none(query):
         return
 
-    if processor is True:
-        processor = default_process
-    elif processor is False:
-        processor = None
-
     if score_cutoff is None:
         score_cutoff = worst_score
 
@@ -163,16 +158,13 @@ def extract_iter(
             continue
 
         if processor is None:
-            score = scorer(
-                query, choice, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
+            score = scorer(query, choice, score_cutoff=score_cutoff, **scorer_kwargs)
         else:
             score = scorer(
                 query,
                 processor(choice),
-                processor=None,
                 score_cutoff=score_cutoff,
-                **kwargs,
+                **scorer_kwargs,
             )
 
         if lowest_score_worst:
@@ -189,10 +181,10 @@ def extractOne(
     choices: Iterable[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, int] | None:
     ...
 
@@ -203,24 +195,23 @@ def extractOne(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, Any] | None:
     ...
 
 
 def extractOne(
     query: Sequence[Hashable] | None,
-    choices: Iterable[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Iterable[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, Any] | None:
     """
     Find the best match in a list of choices. When multiple elements have the same similarity,
@@ -240,20 +231,20 @@ def extractOne(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -267,10 +258,10 @@ def extractOne(
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
             In this case only choices which have a `distance <= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -286,24 +277,24 @@ def extractOne(
     --------
 
     >>> from rapidfuzz.process import extractOne
-    >>> from rapidfuzz.string_metric import levenshtein, normalized_levenshtein
+    >>> from rapidfuzz.distance import Levenshtein
     >>> from rapidfuzz.fuzz import ratio
 
     extractOne can be used with normalized edit distances.
 
     >>> extractOne("abcd", ["abce"], scorer=ratio)
     ("abcd", 75.0, 1)
-    >>> extractOne("abcd", ["abce"], scorer=normalized_levenshtein)
-    ("abcd", 75.0, 1)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.normalized_similarity)
+    ("abcd", 0.75, 1)
 
     extractOne can be used with edit distances as well.
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance)
     ("abce", 1, 0)
 
-    additional settings of the scorer can be passed as keyword arguments to extractOne
+    additional settings of the scorer can be passed via the scorer_kwargs argument to extractOne
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2))
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)})
     ("abcde", 2, 1)
 
     when a mapping is used for the choices the key of the choice is returned instead of the List index
@@ -311,17 +302,13 @@ def extractOne(
     >>> extractOne("abcd", {"key": "abce"}, scorer=ratio)
     ("abcd", 75.0, "key")
 
-    By default each string is preprocessed using `utils.default_process`, which lowercases the strings,
-    replaces non alphanumeric characters with whitespaces and trims whitespaces from start and end of them.
-    This behavior can be changed by passing a custom function, or None to disable the behavior. Preprocessing
-    can take a significant part of the runtime, so it makes sense to disable it, when it is not required.
+    It is possible to specify a processor function which is used to preprocess the strings before comparing them.
 
-
-    >>> extractOne("abcd", ["abdD"], scorer=ratio)
-    ("abcD", 100.0, 0)
-    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=None)
+    >>> extractOne("abcd", ["abcD"], scorer=ratio)
     ("abcD", 75.0, 0)
-    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=lambda s: s.upper())
+    >>> extractOne("abcd", ["abcD"], scorer=ratio, processor=utils.default_process)
+    ("abcD", 100.0, 0)
+    >>> extractOne("abcd", ["abcD"], scorer=ratio, processor=lambda s: s.upper())
     ("abcD", 100.0, 0)
 
     When only results with a similarity above a certain threshold are relevant, the parameter score_cutoff can be
@@ -336,23 +323,20 @@ def extractOne(
 
     For edit distances all results with an edit distance above the score_cutoff are filtered out
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2))
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)})
     ("abce", 2, 0)
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2), score_cutoff=1)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)}, score_cutoff=1)
     None
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    _ = score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
     if _is_none(query):
         return None
 
-    if processor is True:
-        processor = default_process
-    elif processor is False:
-        processor = None
-
     if score_cutoff is None:
         score_cutoff = worst_score
 
@@ -369,16 +353,13 @@ def extractOne(
             continue
 
         if processor is None:
-            score = scorer(
-                query, choice, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
+            score = scorer(query, choice, score_cutoff=score_cutoff, **scorer_kwargs)
         else:
             score = scorer(
                 query,
                 processor(choice),
-                processor=None,
                 score_cutoff=score_cutoff,
-                **kwargs,
+                **scorer_kwargs,
             )
 
         if lowest_score_worst:
@@ -402,11 +383,11 @@ def extract(
     choices: Collection[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
-    limit: int | None = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
+    limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, int]]:
     ...
 
@@ -417,26 +398,25 @@ def extract(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
-    limit: int | None = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
+    limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, Any]]:
     ...
 
 
 def extract(
     query: Sequence[Hashable] | None,
-    choices: Collection[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Collection[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, Any]]:
     """
     Find the best matches in a list of choices. The list is sorted by the similarity.
@@ -456,22 +436,23 @@ def extract(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
-    limit : int
-        maximum amount of results to return
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
+    limit : int, optional
+        maximum amount of results to return. None can be passed to disable this behavior.
+        Default is 5.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
-        edit distance and matches with a `distance <= score_cutoff` are ignored. When a
+        edit distance and matches with a `distance > score_cutoff` are ignored. When a
         normalized edit distance is used this represents the minimal similarity
-        and matches with a `similarity >= score_cutoff` are ignored. Default is None, which deactivates this behaviour.
+        and matches with a `similarity < score_cutoff` are ignored. Default is None, which deactivates this behaviour.
     score_hint : Any, optional
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -484,11 +465,11 @@ def extract(
         * The second value represents the similarity calculated by the scorer. This can be:
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
-            In this case only choices which have a `distance <= max` are returned.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            In this case only choices which have a `distance <= score_cutoff` are returned.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -497,37 +478,40 @@ def extract(
           * The `index of choice` when choices is a simple iterable like a list
           * The `key of choice` when choices is a mapping like a dict, or a pandas Series
 
-        The list is sorted by `score_cutoff` or `max` depending on the scorer used. The first element in the list
+        The list is sorted by similarity or distance depending on the scorer used. The first element in the list
         has the `highest similarity`/`smallest distance`.
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if limit is None:
-        limit = len(choices)
-
     result_iter = extract_iter(
         query,
         choices,
         processor=processor,
         scorer=scorer,
         score_cutoff=score_cutoff,
-        **kwargs,
+        score_hint=score_hint,
+        scorer_kwargs=scorer_kwargs,
     )
+
+    if limit is None:
+        return sorted(result_iter, key=lambda i: i[1], reverse=lowest_score_worst)
+
     if lowest_score_worst:
         return heapq.nlargest(limit, result_iter, key=lambda i: i[1])
     return heapq.nsmallest(limit, result_iter, key=lambda i: i[1])
 
 
-if TYPE_CHECKING:
+with suppress(BaseException):
     import numpy as np
 
 
 def _dtype_to_type_num(
     dtype: np.dtype | None,
     scorer: Callable[..., int | float],
-    **kwargs: dict[str, Any],
+    scorer_kwargs: dict[str, Any],
 ) -> np.dtype:
     import numpy as np
 
@@ -536,7 +520,7 @@ def _dtype_to_type_num(
 
     params = getattr(scorer, "_RF_ScorerPy", None)
     if params is not None:
-        flags = params["get_scorer_flags"](**kwargs)
+        flags = params["get_scorer_flags"](**scorer_kwargs)
         if flags["flags"] & ScorerFlag.RESULT_I64:
             return np.int32
         return np.float32
@@ -544,6 +528,16 @@ def _dtype_to_type_num(
     return np.float32
 
 
+def _is_symmetric(scorer: Callable[..., int | float], scorer_kwargs: dict[str, Any]) -> bool:
+    params = getattr(scorer, "_RF_ScorerPy", None)
+    if params is not None:
+        flags = params["get_scorer_flags"](**scorer_kwargs)
+        if flags["flags"] & ScorerFlag.SYMMETRIC:
+            return True
+
+    return False
+
+
 def cdist(
     queries: Collection[Sequence[Hashable] | None],
     choices: Collection[Sequence[Hashable] | None],
@@ -554,7 +548,7 @@ def cdist(
     score_hint: int | float | None = None,
     dtype: np.dtype | None = None,
     workers: int = 1,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> np.ndarray:
     """
     Compute distance/similarity between each pair of the two collections of inputs.
@@ -567,13 +561,9 @@ def cdist(
         list of all strings the query should be compared
     scorer : Callable, optional
         Optional callable that is used to calculate the matching score between
-        the query and each choice. This can be:
-
-        - a scorer using the RapidFuzz C-API like the builtin scorers in RapidFuzz,
-          which can return a distance or similarity between two strings. Further details can be found here.
-        - a Python function which returns a similarity between two strings in the range 0-100. This is not
-          recommended, since it is far slower than a scorer using the RapidFuzz C-API.
-
+        the query and each choice. This can be any of the scorers included in RapidFuzz
+        (both scorers that calculate the edit distance or the normalized edit distance), or
+        a custom function, which returns a normalized edit distance.
         fuzz.ratio is used by default.
     processor : Callable, optional
         Optional callable that is used to preprocess the strings before
@@ -601,9 +591,9 @@ def cdist(
         Supply -1 to use all available CPU cores.
         This argument is only available for scorers using the RapidFuzz C-API so far, since it
         releases the Python GIL.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -613,42 +603,35 @@ def cdist(
     """
     import numpy as np
 
-    dtype = _dtype_to_type_num(dtype, scorer, **kwargs)
+    _ = workers, score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    dtype = _dtype_to_type_num(dtype, scorer, scorer_kwargs)
     results = np.zeros((len(queries), len(choices)), dtype=dtype)
 
-    if queries is choices:
-        if processor is None:
-            proc_queries = list(queries)
-        else:
-            proc_queries = [processor(x) for x in queries]
+    if processor is None:
+        proc_choices = list(choices)
+    else:
+        proc_choices = [x if _is_none(x) else processor(x) for x in choices]
 
-        for i, query in enumerate(proc_queries):
-            results[i, i] = scorer(
-                query, query, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
-            for j in range(i + 1, len(proc_queries)):
+    if queries is choices and _is_symmetric(scorer, scorer_kwargs):
+        for i, query in enumerate(proc_choices):
+            results[i, i] = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs)
+            for j in range(i + 1, len(proc_choices)):
                 results[i, j] = results[j, i] = scorer(
                     query,
-                    proc_queries[j],
-                    processor=None,
+                    proc_choices[j],
                     score_cutoff=score_cutoff,
-                    **kwargs,
+                    **scorer_kwargs,
                 )
     else:
-        if processor is None:
-            proc_choices = list(choices)
-        else:
-            proc_choices = [processor(x) for x in choices]
-
         for i, query in enumerate(queries):
-            proc_query = processor(query) if processor else query
+            proc_query = processor(query) if (processor and not _is_none(query)) else query
             for j, choice in enumerate(proc_choices):
                 results[i, j] = scorer(
                     proc_query,
                     choice,
-                    processor=None,
                     score_cutoff=score_cutoff,
-                    **kwargs,
+                    **scorer_kwargs,
                 )
 
     return results
